.PHONY:	main.tcl global.tcl irctk all install clean distclean regression-tests man

PREFIX=	M4PREFIX

MANVERSION=	M4MANVER
MANPAGES=	irctk-irc irctk-log irctk-exts irctk-irctk irctk-gui
MANPAGES+=	irctk-extensions irctk

all: main.tcl global.tcl irctk

irctk:
	m4 -DPREFIX=${PREFIX} irctk.m4 >irctk

main.tcl:
	m4 -DPREFIX=${PREFIX} main.m4 >main.tcl

global.tcl:
	m4 -DPREFIX=${PREFIX} global.m4 >global.tcl

install: all
	install -Dm 0444 global.tcl ${PREFIX}/share/irctk/global.tcl
	install -Dm 0444 uuid.tcl ${PREFIX}/share/irctk/uuid.tcl
	install -Dm 0444 main.tcl ${PREFIX}/share/irctk/main.tcl
	install -Dm 0444 irctk.tcl ${PREFIX}/share/irctk/irctk.tcl
	install -Dm 0444 log.tcl ${PREFIX}/share/irctk/log.tcl
	install -Dm 0444 gui.tcl ${PREFIX}/share/irctk/gui.tcl
	install -Dm 0444 irc.tcl ${PREFIX}/share/irctk/irc.tcl
	install -Dm 0444 exts.tcl ${PREFIX}/share/irctk/exts.tcl
	install -Dm 0555 irctk ${PREFIX}/bin/irctk
	install -Dm 0444 ${MANVERSION}/irctk.1 ${PREFIX}/man/man1/irctk.1
	install -Dm 0444 ${MANVERSION}/irctk-extensions.7 ${PREFIX}/man/man7/irctk-extensions.7
	install -Dm 0444 ${MANVERSION}/irctk-irc.n ${PREFIX}/man/mann/irctk-irc.n
	install -Dm 0444 ${MANVERSION}/irctk-log.n ${PREFIX}/man/mann/irctk-log.n
	install -Dm 0444 ${MANVERSION}/irctk-exts.n ${PREFIX}/man/mann/irctk-exts.n
	install -Dm 0444 ${MANVERSION}/irctk-irctk.n ${PREFIX}/man/mann/irctk-irctk.n
	install -Dm 0444 ${MANVERSION}/irctk-gui.n ${PREFIX}/man/mann/irctk-gui.n

clean:
	rm -f main.tcl irctk global.tcl

distclean: clean
	rm Makefile

regression-tests:
	${MAKE} -C regress regress

man: ${MANPAGES}

irctk: man/irctk.1 mdoc/irctk.1

irctk-extensions: man/irctk-extensions.7 mdoc/irctk-extensions.7

irctk-irc: www/wiki/irctk-irc.n.md man/irctk-irc.n mdoc/irctk-irc.n

irctk-log: www/wiki/irctk-log.n.md man/irctk-log.n mdoc/irctk-log.n

irctk-exts: www/wiki/irctk-exts.n.md man/irctk-exts.n mdoc/irctk-exts.n

irctk-irctk: www/wiki/irctk-irctk.n.md man/irctk-irctk.n mdoc/irctk-irctk.n

irctk-gui: www/wiki/irctk-gui.n.md man/irctk-gui.n mdoc/irctk-gui.n

mdoc/irctk.1: irctk.1
	cp irctk.1 mdoc

man/irctk.1: irctk.1
	mandoc -Tman ./irctk.1 >man/irctk.1

mdoc/irctk-extensions.7: irctk-extensions.7
	cp irctk-extensions.7 mdoc

man/irctk-extensions.7: irctk-extensions.7
	mandoc -Tman ./irctk-extensions.7 >man/irctk-extensions.7

www/wiki/irctk-irc.n.md: irctk-irc.n
	mandoc -Tmarkdown ./irctk-irc.n >www/wiki/irctk-irc.n.md

mdoc/irctk-irc.n: irctk-irc.n
	cp irctk-irc.n mdoc

man/irctk-irc.n: irctk-irc.n
	mandoc -Tman ./irctk-irc.n >man/irctk-irc.n

www/wiki/irctk-log.n.md: irctk-log.n
	mandoc -Tmarkdown ./irctk-log.n >www/wiki/irctk-log.n.md

mdoc/irctk-log.n: irctk-log.n
	cp irctk-log.n mdoc

man/irctk-log.n: irctk-log.n
	mandoc -Tman ./irctk-log.n >man/irctk-log.n

www/wiki/irctk-exts.n.md: irctk-exts.n
	mandoc -Tmarkdown ./irctk-exts.n >www/wiki/irctk-exts.n.md

mdoc/irctk-exts.n: irctk-exts.n
	cp irctk-exts.n mdoc

man/irctk-exts.n: irctk-exts.n
	mandoc -Tman ./irctk-exts.n >man/irctk-exts.n

www/wiki/irctk-irctk.n.md: irctk-irctk.n
	mandoc -Tmarkdown ./irctk-irctk.n >www/wiki/irctk-irctk.n.md

mdoc/irctk-irctk.n: irctk-irctk.n
	cp irctk-irctk.n mdoc

man/irctk-irctk.n: irctk-irctk.n
	mandoc -Tman ./irctk-irctk.n >man/irctk-irctk.n

www/wiki/irctk-gui.n.md: irctk-gui.n
	mandoc -Tmarkdown ./irctk-gui.n >www/wiki/irctk-gui.n.md

mdoc/irctk-gui.n: irctk-gui.n
	cp irctk-gui.n mdoc

man/irctk-gui.n: irctk-gui.n
	mandoc -Tman ./irctk-gui.n >man/irctk-gui.n
