.\" Automatically generated from an mdoc input file.  Do not edit.
.\"
.\" Copyright (c) 2023 Andrea Biscuola <a@abiscuola.com>
.\"
.\" Permission to use, copy, modify, and distribute this software for any
.\" purpose with or without fee is hereby granted, provided that the above
.\" copyright notice and this permission notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
.\" WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
.\" MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
.\" ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
.\" WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
.\" ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
.\"
.TH "IRCTK-IRC" "n" "August 18, 2023" "OpenBSD 7.3" "n"
.nh
.if n .ad l
.SH "NAME"
\fBirctk-irc\fR
\- the irctk irc namespace library
.SH "SYNOPSIS"
\fBirc cap\fR \fIchan tags capability\fR
.PP
\fBirc dial\fR \fIcmd callback\fR
.PP
\fBirc join\fR \fIchan tags channels\fR [\fIkeys\fR]
.PP
\fBirc nick\fR \fIchan tags nick\fR
.PP
\fBirc notice\fR \fIchan tags target\fR [\fIargs\fR]
.PP
\fBirc part\fR \fIchan tags channels\fR [\fIargs\fR]
.PP
\fBirc ping\fR \fIchan tags text\fR
.PP
\fBirc pong\fR \fIchan tags text\fR
.PP
\fBirc privmsg\fR \fIchan tags target\fR [\fIargs\fR]
.PP
\fBirc quit\fR \fIchan tags\fR [\fItext\fR]
.PP
\fBirc receive\fR \fIchan\fR
.PP
\fBirc register\fR \fIchan tags user nick pass mode name\fR
.PP
\fBirc send\fR \fIchan tags cmd\fR [\fIargs\fR]
.SH "DESCRIPTION"
The irc namespace implements the IRC client specification as defined in
RFC2812 and a subset of the modern IRCv3 specification.
.PP
The
\fBirc dial\fR
command must be used to establish a connection to an irc server.
\fIcmd\fR
is a shell script that will be launched as a subprocess
and connected to
irctk(1)
through a bidirectional pipe, exchanging IRC commands through the
subprocess standard input and standard output channels.
In effect, the subprocess is responsible for the whole transport layer.
The
\fIcallback\fR
argument will be called whenever new data are ready to on the read side of
the established communication channel and it will be called with the
form:
.PP
.RS 6n
callback chan
.RE
.PP
where
\fIchan\fR
is the communication channel just created.
The returned channel must then be passed to all the other commands
when a specific IRC operation must be performed.
.PP
The
\fBirc receive\fR
command can be called to receive a new IRC message from the specified
\fIchan\fR
message in a structured form.
The command returns a dictionary containing the following fields:
.TP 9n
tags
Dictionary containing all the processed IRCv3 tags stored as key-value
pairs.
.TP 9n
server
The host the message is coming from
.TP 9n
user
The user that sent the message
.TP 9n
nick
The nickname of the user that sent the message, or the server that
forwarded it if it was generated by one of the IRC network servers.
.TP 9n
command
The IRC command.
.TP 9n
args
List of command arguments
.TP 9n
date
Timestamp in UNIX epoch format.
.PP
The
\fBirc send\fR
command can be used to send an IRC message.
The message will be composed by zero or more
\fItags\fR
passed as a dictionary containing a series of key-value pairs, an IRC
command passed as
\fIcmd\fR
and zero or more command arguments in
\fIargs\fR.
.SS "High level commands"
The following high level commands should be used to send commands
to an IRC server.
If a command accept an arguments called
\fItags\fR,
it means, as mentioned, a dictionary of key-value pairs identifying IRCv3
tags unless differently specified.
.PP
\fBirc cap\fR
is used to manage the IRCv3 capabilities subsystem of the server
connected to
\fIchan\fR.
By default, the
\fBirc cap\fR
command will send a
\(lqCAP REQ \fIcapability\fR\(rq
command to the server, asking it to enable
\fIcapability\fR
for the client.
The only exceptions for the
\fIcapability\fR
arguments are:
.TP 8n
ls
Send a
\(lqCAP LS\(rq
command, asking the server for the list of capabilities it supports.
.TP 8n
end
Send a
\(lqCAP END\(rq
command, terminating the capabilities negotiation.
.PP
\fBirc register\fR
can be used to handle the client registration and login process to
the irc server.
If the
\fIpass\fR
argument is an empty string no PASS command will be issued.
.PP
\fBirc join\fR
can be used to join one or more IRC channels.
\fIchannels\fR
and
\fIkeys\fR
are comma-separated lists of IRC channels and related passwords,
in case joining a channel requires one.
.PP
\fBirc part\fR
can be used to leave one or more channels.
As for
\fBirc join\fR,
\fIchannels\fR
is a comma-separated list of channels to leave.
.PP
\fBirc nick\fR
can be used to change the current user nickname.
.PP
\fBirc notice\fR
and
\fBirc privmsg\fR
sends, respectively, a NOTICE or a PRIVMSG command to the IRC server
directed at
\fItarget\fR,
be it a channel or another user nickame.
\fIargs\fR
is a variable-length list of strings that will compose the message to send.
.PP
\fBirc quit\fR
will QUIT the connection with
\fItext\fR
as a reason.
To note that the command does not close
\fIchan\fR.
It's responsibility of the caller to do so, either immediately, or after
receiving the related ERROR response from the irc server.
.PP
\fBirc ping\fR
and
\fBirc pong\fR
are used for the periodic check with the server if the connection is still
alive.
irctk(1)
may initiate e PING, waiting for the server response, or it may answer
with a PONG, if the PING is initiated by the irc server itself.
\fItext\fR
is the message passed to identify the PING or PONG transactions.
.SH "RETURN VALUES"
\fBirc dial\fR
returns the opened bi-directional channel on success, or nothing if
an error occured.
.PP
\fBirc receive\fR
returns a dictionary with the irc command field values, or -1 in case
an error occured during the read from the channel.
.PP
\fBirc send\fR
and all the other commands don't return any value at all.
.PP
In general, errors on the channel are expected to be handled in the
tcl event-loop, as a
\(lqreadable\(rq
event is fired whenever a channel is closed, or if any error happened
on it.
.SH "EXAMPLES"
Dial to libera.chat, using
nc(1)
with TLS and use the
\(lqnewmsg\(rq
Command as a callback:
.nf
.sp
.RS 0n
proc newmsg {ch} {
	set msg [irc receive $ch]

	if {$rmsg == -1} {
		if {[eof $chan]} {
			puts stderr "error on $chan"
			close $chan
		}

		return
	}

	puts $msg
}

irc dial "nc -c irc.libera.chat 6697" newmsg
.RE
.fi
.SH "SEE ALSO"
irctk(1),
irctk-exts(n),
irctk-gui(n),
irctk-irctk(n),
irctk-log(n)
.SH "AUTHORS"
Andrea Biscuola <\fIa@abiscuola.com\fR>
.br
Omar Polo <\fIop@omarpolo.com\fR>
