IRCTK-IRC(n) - n

# NAME

**irctk-exts** - irctk extensions subsystem

# SYNOPSIS

**exts bootstrapped**

**exts init**

**exts killbyname** *name*

**exts list**

**exts load** *path* *cb*

**exts newmsg**

**exts readmsg** *ch* *cb*

**exts writemsg** *msg*

# DESCRIPTION

The exts namespace, takes care of loading, and running, irctk extension
executables.
The subsystem completely takes care of the extensions management, with
the only communications with the other layers defined by the exported
functions.

**exts bootstrapped**
checks, during application startup, if all the configured extensions are
started properly, before continuing with the other parts of the process.

**exts init**
initializes the subsystem, loading the extensions at startup, both from the
extension default directory and the irctk extensions configurations file.

**exts killbyname**
unloads an extension identified by the
*name*
it communicated to irctk.
All the unloaded extension related resources are cleared by this command.

**exts list**
provides a tcl list with all the extensions actually running.
Every extension is represented in the list by three fields, in the following
order:

Name

> The extension name, as reported during the handshake.

Version

> Extension version number.

Path

> The extension executable file path.

**exts load**
runs a new extension from the file at
*path*.
If the handshake between the application and the extension is successful,
messages coming from the extension are passed to the callback command
*cb*
after being processed.

**exts newmsg**
returns an empty dictionary ready to be filled to be sent to the extensions
subsystem.

**exts readmsg**
read a message from the extension channel
*ch*
and passes it to the callback
*cb*
after processing it.
The callback is called with the form:

	$cb $msg

Where
"$msg"
is a dictionary containing all the values of the received message.

**exts writemsg**
is used to pass an extension message to be written to all the running extensions
from irctk.
The message is a dictionary containing the fields related to the message type.
A message can be of type irc or plumb.
Please refer to the extensions protocol specification for additional details.

# RETURN VALUES

**exts list**
returns the list of loaded extensions.

**exts killbyname**
always return the empty string.

**exts writemsg**
returns 0 on success or &lt;0 if an error occur.

**exts load**
return 0 if the extension already exists, the new communication channel if
the load of the extension is successful and &lt;0 if an error occur.

# FILES

*${PREFIX}/libexec*

> Default extensions directory.

*${HOME}/.config/irctk/extensions.conf*

> irctk(1)
> loaded extensions save file.

# SEE ALSO

irctk(1),
irctk-gui(n),
irctk-irc(n),
irctk-irctk(n),
irctk-log(n)

# AUTHORS

Andrea Biscuola &lt;[a@abiscuola.com](mailto:a@abiscuola.com)&gt;

OpenBSD 7.3 - September 3, 2023
